@@ -499,8 +499,7 @@ def VersionMatch(version, pattern):
 
 
 def _GetVersionTuple(pattern, versions):
-    """Extract the version tuple corresponding to version 'pattern'.
-    """
+    """Extract the version tuple corresponding to version 'pattern'."""
     if not versions:
         # No need to go on if the versions list is empty
         return None
@@ -701,8 +700,7 @@ class GetNightlyCMTPROJECTPATH(ContentHandler):
             raise TypeError("What do you mean with day = %r?" % day)
 
     def startElement(self, name, attrs):
-        """SAX implementation.
-        """
+        """SAX implementation."""
         if name == "slot":
             if attrs["name"] == self.slot:
                 self._in_slot = True
@@ -713,16 +711,14 @@ class GetNightlyCMTPROJECTPATH(ContentHandler):
                 self._path.append(attrs["value"])
 
     def endElement(self, name):
-        """SAX implementation.
-        """
+        """SAX implementation."""
         if name == "slot":
             self._in_slot = False
         elif name == "cmtprojectpath":
             self._in_cmtpp = False
 
     def dirs(self):
-        """Return the list of entries in the CMTPROJECTPATH.
-        """
+        """Return the list of entries in the CMTPROJECTPATH."""
         today = days[self._day]
         yesterday = days[self._day - 1]
         d = [
@@ -732,8 +728,7 @@ class GetNightlyCMTPROJECTPATH(ContentHandler):
         return d
 
     def value(self):
-        """Return the CMTPROJECTPATH.
-        """
+        """Return the CMTPROJECTPATH."""
         return os.path.pathsep.join(self.dirs())
 
 
@@ -788,8 +783,7 @@ def smartExpandVarsPath(path, env=None):
 
 
 def uniq(iterable):
-    """Returns a list of unique elements in the passed iterable.
-    """
+    """Returns a list of unique elements in the passed iterable."""
     result = []
     for i in iterable:
         if i not in result:
@@ -2522,8 +2516,15 @@ class Comp(SetupProject):
             dest="outshell",
             help="Print the environment as Python " "dictionary.",
         )
+        parser.add_option(
+            "-A",
+            "--all",
+            action="store_true",
+            help="Print all variables, instead of just the changes, with --sh, --csh and --py.",
+        )
         parser.add_option("--container", help="ignored")
         parser.add_option("--allow-containers", action="store_true", help="ignored")
+        parser.add_option("--disallow-containers", action="store_true", help="ignored")
         parser.add_option("--prefer-container", action="store_true", help="ignored")
         return parser
 
