@@ -66,6 +66,7 @@ def test_platform_sorting():
         "x86_64-centos7-gcc62-opt",
         "x86_64-centos7-gcc7-opt",
         "x86_64-centos7-gcc8-opt",
+        "x86_64-centos7-gcc10+py3-opt",
         "x86_64-centos7-gcc10-opt",
         "x86_64+avx2+fma-centos7-gcc62-opt",
     ]
@@ -600,7 +601,14 @@ def test_incompatibility_report():
 
     try:
         check_output(
-            ["lb-run", "--platform", "x86_64-slc5-gcc43-opt", "LHCb/v31r6p1", "true"],
+            [
+                "lb-run",
+                "--disallow-containers",
+                "--platform",
+                "x86_64-slc5-gcc43-opt",
+                "LHCb/v31r6p1",
+                "true",
+            ],
             stderr=STDOUT,
         )
         assert False, "script failure expected"
@@ -608,4 +616,6 @@ def test_incompatibility_report():
         print(err.output)
         import re
 
-        assert re.search(r"dirac_platform: [^-]+-{}".format(os_id()), err.output)
+        assert re.search(
+            r"dirac_platform: [^-]+-{}".format(os_id()), err.output.decode()
+        )
